@@ -37,3 +37,23 @@ def test_code_indent():
     assert show == "print('asdf')\n" \
                    "    print('1234')\n" \
                    "  # comment"
+
+
+def test_code_split_empty():
+    show, run = get_show_exec_code([''])
+    assert show == ''
+    assert run == ''
+
+
+def test_code_no_show():
+    code = '# - hide: start -\nprint("l1")\nprint("l2")'
+    show, run = get_show_exec_code(code.splitlines())
+    assert show == ''
+    assert run == 'print("l1")\nprint("l2")'
+
+
+def test_code_no_exec():
+    code = '# - skip: start -\nprint(1 / 0)\nprint(2 / 0)'
+    show, run = get_show_exec_code(code.splitlines())
+    assert show == 'print(1 / 0)\nprint(2 / 0)'
+    assert run == ''
